# EeAPT Confirm

This package provide as script `eeapt-confirm` declared as a `DPkg::Pre-Install-Pkgs` hook in APT configuration. This hook allow to protect debian packages of unwanted installation/upgrades by asking user for confirmation in interactive mode and deny it in non-interactive mode. By default, all packages are protected, but you can limit it by editing the configuration.

## Configuration

The configuration is stored in the `/etc/eeapt-confirm.conf` [INI style file](https://metacpan.org/pod/Config::Tiny) and contain the following parameters:

* `confirm_text`: the text of the confirmation prompt show to user in interactive mode. Note: expected user answer is `Y` (yes) or `N` (no, default) and the prompt should display it.
* `noninteractive_text`: the error returned in non-interactive mode to explain why the installation/upgrade is denied.
* `packages_regex`: an optional regular expression (PCRE) used to limit the protection to some packages. If defined, the package name must matched to be protected. Some examples:

  * `asterisk`: protect all packages that contain the `asterisk` keyword in their name
  * `(apache|php)`: protect all packages that contain the `apache` or `php` keywords in their name
  * `^vim$`: only protect the package `vim`


## Publish a new release

- Make all changes needs in the ''master'' branch with explicit commits messages that will be used to compose the Debian changelog entries
- add the version tag: ''git tag 1.0''
- push changes to remote repository: ''git push && git push --tags''


## Locally build (using Docker)

You also could manually build a specific release using the following command:

```bash
docker run --rm -it -v "$(pwd):/src" -w /src -e DEBFULLNAME -e DEBEMAIL -e GPG_KEY debian:11 ./build.sh --install-build-deps
```

Release builded files will be store in the `dist` directory.

### Packages signing

By default, builded packages are not signed but you could provided information to allow their signature :

- be sure to define `DEBFULLNAME` and `DEBEMAIL` environment variables
- run the `docker run` command in a context where the `GPG_KEY` environment variable is set as follow :

```bash
GPG_KEY=$( gpg --armor --export-secret-key $DEBEMAIL|base64|tr -d '\n' )
```

**Important :** This solution only work with GPG key **without password** defined. If you have to use a GPG key with a password, you have to remove it before by running the following command :

```
gpg --edit-key $DEBEMAIL
> passwd
> quit
```

Be sure to restore your password after building the Debian packages.

**Note :** the `build.sh` script accept a `--gpg-key` parameter, but it will only works if the GPG key is available in the running context, so probably not in a docker container or not if script is run with `sudo`.
